Crate alisa

Crate alisa 

Re-exports

pub use rmpv;
pub use paste;

Macros

object_set_property_delta
object_set_property_operation
project_set_property_delta
project_set_property_operation
tree_object_creation_operations
tree_object_operations
tree_object_transfer_operation

Structs

Action
ChildList
ChildListTreeData
Client
ClientId
DeleteObjectDelta
DeserializationContext
InsertChildDelta
LoadingPtr
A reference to an object that indicates that the object refered to should be loaded from disk/the server when the referer is loaded.
ObjList
ObjectKind
OperationKind
A kind of operation, stored as a struct in Project::OPERATIONS.
ProjectContext
Ptr
A reference to an object
Recorder
RecreateObjectDelta
RemoveChildDelta
SerializationContext
Server
SetParentDelta
UndoRedoManager
UnorderedChildList
UnorderedChildListTreeData

Traits

Children
A list of references to the children of a tree object
Delta
A tiny change to the project. Used for moving backwards in time for the collaboration conflict resolution system.
Object
Operation
An operation performed on the project. Operations can be inverted for undo/redo. Note that when collaborating, undoing an operation and redoing might not return to the original state of the project.
Project
Serializable
TreeObj
An object that is part of a tree of objects.

Functions

rmpv_decode
rmpv_encode
rmpv_get

Derive Macros

Serializable