Re-exports
Macros
- object_
set_ property_ delta - object_
set_ property_ operation - project_
set_ property_ delta - project_
set_ property_ operation - tree_
object_ creation_ operations - tree_
object_ operations - tree_
object_ transfer_ operation
Structs
- Action
- Child
List - Child
List Tree Data - Client
- Client
Id - Delete
Object Delta - Deserialization
Context - Insert
Child Delta - Loading
Ptr - A reference to an object that indicates that the object refered to should be loaded from disk/the server when the referer is loaded.
- ObjList
- Object
Kind - Operation
Kind - A kind of operation, stored as a struct in
Project::OPERATIONS. - Project
Context - Ptr
- A reference to an object
- Recorder
- Recreate
Object Delta - Remove
Child Delta - Serialization
Context - Server
- SetParent
Delta - Undo
Redo Manager - Unordered
Child List - Unordered
Child List Tree Data
Traits
- Children
- A list of references to the children of a tree object
- Delta
- A tiny change to the project. Used for moving backwards in time for the collaboration conflict resolution system.
- Object
- Operation
- An operation performed on the project. Operations can be inverted for undo/redo. Note that when collaborating, undoing an operation and redoing might not return to the original state of the project.
- Project
- Serializable
- TreeObj
- An object that is part of a tree of objects.